==> openshift-model-5.12.0-sources.jar: io/fabric8/openshift/api/model/SourceBuildStrategyBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SourceBuildStrategyBuilder extends io.fabric8.openshift.api.model.SourceBuildStrategyFluentImpl<io.fabric8.openshift.api.model.SourceBuildStrategyBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.SourceBuildStrategy,io.fabric8.openshift.api.model.SourceBuildStrategyBuilder>{
  public SourceBuildStrategyBuilder() {
    this(false);
  }
  public SourceBuildStrategyBuilder(java.lang.Boolean validationEnabled) {
    this(new SourceBuildStrategy(), validationEnabled);
  }
  public SourceBuildStrategyBuilder(io.fabric8.openshift.api.model.SourceBuildStrategyFluent<?> fluent) {
    this(fluent, false);
  }
  public SourceBuildStrategyBuilder(io.fabric8.openshift.api.model.SourceBuildStrategyFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SourceBuildStrategy(), validationEnabled);
  }
  public SourceBuildStrategyBuilder(io.fabric8.openshift.api.model.SourceBuildStrategyFluent<?> fluent,io.fabric8.openshift.api.model.SourceBuildStrategy instance) {
    this(fluent, instance, false);
  }
  public SourceBuildStrategyBuilder(io.fabric8.openshift.api.model.SourceBuildStrategyFluent<?> fluent,io.fabric8.openshift.api.model.SourceBuildStrategy instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withEnv(instance.getEnv()); 
    fluent.withForcePull(instance.getForcePull()); 
    fluent.withFrom(instance.getFrom()); 
    fluent.withIncremental(instance.getIncremental()); 
    fluent.withPullSecret(instance.getPullSecret()); 
    fluent.withScripts(instance.getScripts()); 
    fluent.withVolumes(instance.getVolumes()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SourceBuildStrategyBuilder(io.fabric8.openshift.api.model.SourceBuildStrategy instance) {
    this(instance,false);
  }
  public SourceBuildStrategyBuilder(io.fabric8.openshift.api.model.SourceBuildStrategy instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withEnv(instance.getEnv()); 
    this.withForcePull(instance.getForcePull()); 
    this.withFrom(instance.getFrom()); 
    this.withIncremental(instance.getIncremental()); 
    this.withPullSecret(instance.getPullSecret()); 
    this.withScripts(instance.getScripts()); 
    this.withVolumes(instance.getVolumes()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.SourceBuildStrategyFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.SourceBuildStrategy build() {
    SourceBuildStrategy buildable = new SourceBuildStrategy(fluent.getEnv(),fluent.getForcePull(),fluent.getFrom(),fluent.getIncremental(),fluent.getPullSecret(),fluent.getScripts(),fluent.getVolumes());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SourceBuildStrategyBuilder that = (SourceBuildStrategyBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-6.3.1-sources.jar: io/fabric8/openshift/api/model/SourceBuildStrategyBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class SourceBuildStrategyBuilder extends SourceBuildStrategyFluentImpl<SourceBuildStrategyBuilder> implements VisitableBuilder<SourceBuildStrategy,SourceBuildStrategyBuilder>{
  public SourceBuildStrategyBuilder() {
    this(false);
  }
  public SourceBuildStrategyBuilder(Boolean validationEnabled) {
    this(new SourceBuildStrategy(), validationEnabled);
  }
  public SourceBuildStrategyBuilder(SourceBuildStrategyFluent<?> fluent) {
    this(fluent, false);
  }
  public SourceBuildStrategyBuilder(SourceBuildStrategyFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new SourceBuildStrategy(), validationEnabled);
  }
  public SourceBuildStrategyBuilder(SourceBuildStrategyFluent<?> fluent,SourceBuildStrategy instance) {
    this(fluent, instance, false);
  }
  public SourceBuildStrategyBuilder(SourceBuildStrategyFluent<?> fluent,SourceBuildStrategy instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withEnv(instance.getEnv()); 
    fluent.withForcePull(instance.getForcePull()); 
    fluent.withFrom(instance.getFrom()); 
    fluent.withIncremental(instance.getIncremental()); 
    fluent.withPullSecret(instance.getPullSecret()); 
    fluent.withScripts(instance.getScripts()); 
    fluent.withVolumes(instance.getVolumes()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SourceBuildStrategyBuilder(SourceBuildStrategy instance) {
    this(instance,false);
  }
  public SourceBuildStrategyBuilder(SourceBuildStrategy instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withEnv(instance.getEnv()); 
    this.withForcePull(instance.getForcePull()); 
    this.withFrom(instance.getFrom()); 
    this.withIncremental(instance.getIncremental()); 
    this.withPullSecret(instance.getPullSecret()); 
    this.withScripts(instance.getScripts()); 
    this.withVolumes(instance.getVolumes()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  SourceBuildStrategyFluent<?> fluent;
  Boolean validationEnabled;
  public SourceBuildStrategy build() {
    SourceBuildStrategy buildable = new SourceBuildStrategy(fluent.getEnv(),fluent.getForcePull(),fluent.getFrom(),fluent.getIncremental(),fluent.getPullSecret(),fluent.getScripts(),fluent.getVolumes());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
